@@ -1,5 +1,5 @@
 import os
-import rpyc  # type: ignore
+from typing import List
 from shutil import rmtree, move
 import sqlite3
 import json
@@ -7,8 +7,10 @@ from multiprocessing import Pool
 from pathlib import Path
 import fire  # type: ignore
 from tqdm import tqdm  # type: ignore
+import rpyc  # type: ignore
 from .persistor import Persistor
 from .graph import graph
+from .utils import remove_symlink
 
 
 class HyperTag:
@@ -160,6 +162,10 @@ class HyperTag:
         if _return:
             return results
 
+    def add_auto_import_dir(self, path: str):
+        """ Add path for auto import directory (watched by daemon) """
+        self.db.add_auto_import_directory(path)
+
     def set_hypertagfs_dir(self, path: str):
         """ Set path for HyperTagFS directory """
         self.db.set_hypertagfs_dir(path)
@@ -185,9 +191,10 @@ class HyperTag:
             file_paths_names = self.db.get_file_paths_names_by_tag_id(tag_id)
             if len(file_paths_names) > 0:
                 underscore_root_tag_path = root_path / ("_" + name)
-                os.makedirs(underscore_root_tag_path, exist_ok=True)
-                root_tag_path = root_path / (name)
-                move(underscore_root_tag_path, root_tag_path)  # Needed for daemon
+                root_tag_path = root_path / name
+                if not root_tag_path.exists():
+                    os.makedirs(underscore_root_tag_path, exist_ok=True)
+                    move(underscore_root_tag_path, root_tag_path)  # Needed for daemon
                 symlink_path = root_tag_path
                 if tag_id not in leaf_tag_ids:
                     symlink_path = root_tag_path / "_files"
@@ -199,7 +206,27 @@ class HyperTag:
                         pass
                 self.mount(root_tag_path, tag_id)
 
-    def import_tags(self, import_path: str):
+    def auto_add_tags_from_path(
+        self, file_path: str, import_path_dirs: List[str], verbose=False, keep_all=False
+    ):
+        file_path_tags = [p for p in str(file_path).split("/") if p not in import_path_dirs]
+        if not keep_all:
+            file_path_tags = file_path_tags[:-1]
+        if verbose:
+            print("Inferred tags:", file_path_tags)
+        self.tag(
+            file_path.name,
+            "with",
+            *file_path_tags,
+            remount=False,
+            add=False,
+            commit=False,
+        )
+        for previous, current in zip(file_path_tags, file_path_tags[1:]):
+            self.metatag(current, "with", previous, remount=False, commit=False)
+        # print(file_path_tags, file_path.name)
+
+    def import_tags(self, import_path: str, only_tags=False, verbose=False):
         """Import files with tags inferred from existing directory hierarchy
         (ignores hidden directories)"""
         file_paths = [p for p in list(Path(import_path).rglob("*")) if p.is_file()]
@@ -214,27 +241,24 @@ class HyperTag:
             if not is_hidden:
                 visible_file_paths.append(p)
         print("Adding files...")
-        added_file_paths = self.add(*visible_file_paths)
+        if only_tags:
+            added_file_paths = visible_file_paths
+        else:
+            added_file_paths = self.add(*visible_file_paths)
         import_path_dirs = set(str(import_path).split("/"))
         print("Adding tags...")
         for file_path in tqdm(added_file_paths):
-            file_path_tags = [p for p in str(file_path).split("/") if p not in import_path_dirs][
-                :-1
-            ]
-            self.tag(
-                file_path.name,
-                "with",
-                *file_path_tags,
-                remount=False,
-                add=False,
-                commit=False,
-            )
-            for previous, current in zip(file_path_tags, file_path_tags[1:]):
-                self.metatag(current, "with", previous, remount=False, commit=False)
-            # print(file_path_tags, file_path.name)
+            self.auto_add_tags_from_path(file_path, import_path_dirs, verbose)
         self.db.conn.commit()
         self.mount(self.root_dir)
 
+    def remove(self, *file_names):
+        """ Remove files """
+        for file_name in tqdm(file_names):
+            self.db.remove_file(file_name)
+            remove_symlink(self.root_dir, file_name)
+        self.mount(self.root_dir)
+
     def add(self, *file_paths):
         """ Add file/s """
         added = []
@@ -343,6 +367,7 @@ class HyperTag:
             # print("Tagged", file_name, "with", tags)
         if commit:
             self.db.conn.commit()
+        # TODO: Remove symlink (get all paths from metatags)
         # Remount (everything is mounted)
         if remount:
             self.mount(self.root_dir)
@@ -436,6 +461,7 @@ def main():
     fire_cli = {
         "help": help,
         "add": ht.add,
+        "remove": ht.remove,
         "import": ht.import_tags,
         "tag": ht.tag,
         "t": ht.tag,
@@ -449,6 +475,7 @@ def main():
         "query": ht.query,
         "q": ht.query,
         "set_hypertagfs_dir": ht.set_hypertagfs_dir,
+        "add_auto_import_dir": ht.add_auto_import_dir,
         "mount": ht.mount,
         "daemon": daemon,
         "graph": graph,
