@@ -54,7 +54,7 @@ class CLIPVectorizer:
         query_vector = None
         # Check if text_query is an image file path
         file_path = Path(text_query)
-        if file_path.exists():
+        if file_path.exists() and file_path.is_file():
             file_type_guess = filetype.guess(str(file_path))
             if file_type_guess and file_type_guess.extension in {"jpg", "png"}:
                 query_vector = self.encode_image(str(file_path))
@@ -115,7 +115,10 @@ class CLIPVectorizer:
         return image_features
 
     def encode_text(self, text: str):
-        text_tokens = [self.tokenizer.encode("This is " + text + "<|endoftext|>")]
+        sot_token = self.tokenizer.encoder["<|startoftext|>"]
+        eot_token = self.tokenizer.encoder["<|endoftext|>"]
+        text_token = self.tokenizer.encode(text)
+        text_tokens = [[sot_token] + text_token + [eot_token]]
         text_input = torch.zeros(len(text_tokens), self.model.context_length, dtype=torch.long)
 
         for i, tokens in enumerate(text_tokens):
